
--[[

The complete parsing function. Since the order of text in the combat log is likely to differ in
different languages, this entire function is included  in the localization class.

The function is given an input line from the combat log, and parses that line to determine its meaning.
The final step in each section is to return the extracted values. These lines need not be updated, but
the correct info must be extracted into the relevant fields.

Note the use of numeric values for avoids, critical hits, dmg types, and morale/power. These numbers
correspond to the orderings in the four lists directly above this comment block.

You will need to know something about lua pattern matching and/or regex's to attempt to translate this
section. See http://www.lua.org/pil/20.2.html for more details.

]]--

L["Parse"] = function(line)

	-- 1) Damage line ---
	-- Zimba a infligé un coup avec Corps à corps ordinaire rapide inter. sur le Bouc des plaines pour 119 points de type Commun à l'entité Moral.
	local initiatorName,avoidAndCrit,skillName,targetNameAmountAndType = string.match(line,"^(.*) a infligé un (.*) avec (.*) sur (.*)%.$"); -- (updated in v4.1.0)
	
	if (initiatorName ~= nil) then
		
		--initiatorName = string.gsub(initiatorName,"^[Ll]e ","");
		
		local avoidType =
			string.match(avoidAndCrit,"^partially blocked") and 8 or
			string.match(avoidAndCrit,"^partially parried") and 9 or
			string.match(avoidAndCrit,"^partially evaded") and 10 or 1;
		local critType =
			string.match(avoidAndCrit,"coup critique") and 2 or
			string.match(avoidAndCrit,"coup dévastateur") and 3 or 1;
		--skillName = string.match(skillName,"^ avec (.*)$") or L.DirectDamage; -- (as of v4.1.0)
		--sur le Barghest croc-froid pour 13 points de type Commun à l'entité Moral.
		local targetName,amount,dmgType,moralePower = string.match(targetNameAmountAndType,"^(.*) pour ([%d,]*) points de type (.*) à l'entité (.*)$");
		-- damage was absorbed
		if targetName == nil then
			--targetName = string.gsub(targetNameAmountAndType,"^[Ll]e ","");
			amount = 0;
			dmgType = 10;
			moralePower = 3;
		-- some damage was dealt
		else
			--targetName = string.gsub(targetName,"^[Ll]e ","");
			amount = string.gsub(amount,",","")+0;
			-- note there may be no damage type
			dmgType = 
				dmgType == "Commun " and 1 or
				dmgType == "Feu " and 2 or
				dmgType == "Foudre " and 3 or
				dmgType == "Froid " and 4 or
				dmgType == "Acide " and 5 or
				dmgType == "Ombrage " and 6 or
				dmgType == "Lumière " and 7 or
				dmgType == "Beleriand " and 8 or
				dmgType == "Westernesse " and 9 or
				dmgType == "Ancient Dwarf-make " and 10 or 11;
			moralePower = (moralePower == "Moral" and 1 or moralePower == "Puissance" and 2 or 3);
		end
		
		-- Currently ignores damage to power
		if (moralePower == 2) then return nil end
		
		-- Update
		return 1,initiatorName,targetName,skillName,amount,avoidType,critType,dmgType;
	end
	
	-- 2) Heal line --
	--     (note the distinction with which self heals are now handled)
	--     (note we consider the case of heals of zero magnitude, even though they presumably never occur)
	--Mirendir a appliqué un soin avec Prêt de puissance Zimba, redonnant 1,124 points à Puissance
	--Mirendir a appliqué un soin critique avec Espoir Zimba, redonnant 2,810 points à Moral.
	local initiatorName,crit,skillNameTargetNameAmountAndType = string.match(line,"^(.*) a appliqué un (.*) avec (.*)%.$");
	
	if (initiatorName ~= nil) then
		initiatorName = string.gsub(initiatorName,"^[Ll]e ","");
		local critType =
			crit == "soin critique" and 2 or
			crit == "soin dévastateur" and 3 or 1;
		
		local skillNameTargetNameAndAmount,ending = string.match(skillNameTargetNameAmountAndType,"^(.*) (.*)$");
		local targetName,skillName,amount;
		moralePower = (ending == "Moral" and 1 or (ending == "Puissance" and 2 or 3));
		-- heal was absorbed (unfortunately it appears this actually shows as a "hit" instead, so we never get into the first conditional)
		if (moralePower == 3) then
			targetName = string.gsub(ending,"^[Ll]e ","");
			amount = 0;
			-- skill name will equal nil if this was a self heal
			skillName = string.match(skillNameTargetNameAndAmount,"^avec (.*) $");
		-- heal applied
		else
			skillName,targetName,amount = string.match(skillNameTargetNameAndAmount,"^(.*) (.*), redonnant ([%d,]*) points $");
			targetName = string.gsub(targetName,"^[Ll]e ","");
			amount = string.gsub(amount,",","")+0;
			-- skill name will equal nil if this was a self heal
			skillName = string.match(skillName,"^avec (.*) $");
		end
		
		-- rearrange if this was a self heal
		if (skillName == nil) then
			skillName = initiatorName;
			initiatorName = targetName;
		end
		
		-- Update
		return (moralePower == 2 and 4 or 3),initiatorName,targetName,skillName,amount,critType;
	end
	
	-- 3) Buff line --
	
	local initiatorName,skillName,targetName = string.match(line,"^(.*) applied a benefit with (.*) on (.*)%.$");
	
	if (initiatorName ~= nil) then
		initiatorName = string.gsub(initiatorName,"^[Ll]e ","");
		targetName = string.gsub(targetName,"^[Ll]e ","");
		
		-- Update
		return 17,initiatorName,targetName,skillName;
	end
	
	-- 4) Avoid line --
	local initiatorNameMiss,skillName,targetNameAvoidType = string.match(line,"^(.*) to use (.*) on (.*)%.$");
	
	if (initiatorNameMiss ~= nil) then
		initiatorName = string.match(initiatorNameMiss,"^(.*) tried$");
		local targetName, avoidType;
		-- standard avoid
		if (initiatorName ~= nil) then
			initiatorName = string.gsub(initiatorName,"^[Ll]e ","");
			targetName,avoidType = string.match(targetNameAvoidType,"^(.*) but (.*) the attempt$");
			targetName = string.gsub(targetName,"^[Ll]e ","");
			avoidType = 
				string.match(avoidType," blocked$") and 5 or
				string.match(avoidType," parried$") and 6 or
				string.match(avoidType," evaded$") and 7 or
				string.match(avoidType," resisted$") and 4 or
				string.match(avoidType," was immune to$") and 3 or 1;
				
		-- miss
		else
			initiatorName = string.match(initiatorNameMiss,"^(.*) missed trying$");
			initiatorName = string.gsub(initiatorName,"^[Ll]e ","");
			targetName = string.gsub(targetNameAvoidType,"^[Ll]e ","");
			avoidType = 2;
		end
		
		-- Sanity check: must have avoided in some manner
		if (avoidType == 1) then return nil end
		
		-- Update
		return 1,initiatorName,targetName,skillName,0,avoidType,1,10;
	end
	
	-- 5) Reflect line --
	
	local initiatorName,amount,dmgType,targetName = string.match(line,"^(.*) reflected ([%d,]*) (.*) to the Morale of (.*)%.$");
	
	if (initiatorName ~= nil) then
		local skillName = "Reflect";
		initiatorName = string.gsub(initiatorName,"^[Ll]e ","");
		targetName = string.gsub(targetName,"^[Ll]e ","");
		amount = string.gsub(amount,",","")+0;
		
		local dmgType = string.match(dmgType,"^(.*)damage$");
		-- a damage reflect
		if (dmgType ~= nil) then
			dmgType = 
				dmgType == "Commun " and 1 or
				dmgType == "Feu " and 2 or
				dmgType == "Foudre " and 3 or
				dmgType == "Froid " and 4 or
				dmgType == "Acide " and 5 or
				dmgType == "Ombrage " and 6 or
				dmgType == "Lumière " and 7 or
				dmgType == "Beleriand " and 8 or
				dmgType == "Westernesse " and 9 or
				dmgType == "Ancient Dwarf-make " and 10 or 11;
						
			-- Update
			return 1,initiatorName,targetName,skillName,amount,1,1,dmgType;
		-- a heal reflect
		else
			-- Update
			return 3,initiatorName,targetName,skillName,amount,1;
		end
	end
	
	-- 6) Temporary Morale bubble line (as of 4.1.0)
  local amount = string.match(line,"^You have lost ([%d,]*) points of temporary Morale!$");
	if (amount ~= nil) then
		amount = string.gsub(amount,",","")+0;
		
		-- the only information we can extract directly is the target and amount
		return 14,nil,player.name,nil,amount;
	end
	
	-- 7) Combat State Break notice (as of 4.1.0)
	
	-- 7a) Root broken
	local targetName = string.match(line,"^.* ha[sv]e? released (.*) from being immobilized!$");
	if (targetName ~= nil) then
		targetName = string.gsub(targetName,"^[Ll]e ","");
		
		-- the only information we can extract directly is the target name
		return 16,nil,targetName,nil;
	end
	
	-- 7b) Daze broken
	local targetName = string.match(line,"^.* ha[sv]e? freed (.*) from a daze!$");
	if (targetName ~= nil) then
		targetName = string.gsub(targetName,"^[Ll]e ","");
		
		-- the only information we can extract directly is the target name
		return 16,nil,targetName,nil;
	end
	
	-- more?
	
	-- 8) Interrupt line --
	
	local targetName, initiatorName = string.match(line,"^(.*) was interrupted by (.*)!$");
	
	if (targetName ~= nil) then
		initiatorName = string.gsub(initiatorName,"^[Ll]e ","");
		targetName = string.gsub(targetName,"^[Ll]e ","");
		
		-- Update
		return 7,initiatorName,targetName;
	end
	
	-- 9) Dispell line (corruption removal) --
	
	local corruption, targetName = string.match(line,"You have dispelled (.*) from (.*)%.$");
	
	if (corruption ~= nil) then
		initiatorName = player.name;
		targetName = string.gsub(targetName,"^[Ll]e ","");
		
		-- NB: Currently ignore corruption name
		
		-- Update
		return 8,initiatorName,targetName;
	end
	
	-- 10) Defeat lines ---
	
	-- 10a) Defeat line 1 (mob or played was killed)
	local initiatorName = string.match(line,"^.* defeated (.*)%.$");
	
	if (initiatorName ~= nil) then
		initiatorName = string.gsub(initiatorName,"^[Ll]e ","");
		
		-- Update
		return 9,initiatorName;
	end
	
	-- 10b) Defeat line 2 (mob died)
	local initiatorName = string.match(line,"^(.*) died%.$");

	if (initiatorName ~= nil) then
		initiatorName = string.gsub(initiatorName,"^[Ll]e ","");
		
		-- Update
		return 9,initiatorName;
	end
	
	-- 10c) Defeat line 3 (a player was killed or died)
	local initiatorName = string.match(line,"^(.*) has been defeated%.$");

	if (initiatorName ~= nil) then
		initiatorName = string.gsub(initiatorName,"^[Ll]e ","");
		
		-- Update
		return 9,initiatorName;
	end
	
	-- 10d) Defeat line 4 (you were killed)
	local match = string.match(line,"^.* incapacitated you%.$");

	if (match ~= nil) then
		initiatorName = player.name;
		
		-- Update
		return 9,initiatorName;
	end
	
	-- 10e) Defeat line 5 (you died)
	local match = string.match(line,"^You have been incapacitated by misadventure%.$");

	if (match ~= nil) then
		initiatorName = player.name;
		
		-- Update
		return 9,initiatorName;
	end
	
	-- 11) Revive lines --
	
	-- 11a) Revive line 1 (player revived)
	local initiatorName = string.match(line,"^(.*) has been revived%.$");
	
	if (initiatorName ~= nil) then
	  initiatorName = string.gsub(initiatorName,"^[Ll]e ","");
	  
		-- Update
	  return 10,initiatorName;
	end
	
	-- 11b) Revive line 2 (player succumbed)
	local initiatorName = string.match(line,"^(.*) has succumbed to .* wounds%.$");
	
	if (initiatorName ~= nil) then
	  initiatorName = string.gsub(initiatorName,"^[Ll]e ","");
	  
		-- Update
	  return 10,initiatorName;
	end
	
	-- 11c) Revive line 3 (you were revived)
	local match = string.match(line,"^You have been revived%.$");
	
	if (match ~= nil) then
	  initiatorName = player.name;
	  
		-- Update
	  return 10,initiatorName;
	end
	
	-- 11d) Revive line 4 (you succumbed)
	local match = string.match(line,"^You succumb to your wounds%.$");
	
	if (match ~= nil) then
	  initiatorName = player.name;
	  
		-- Update
	  return 10,initiatorName;
	end
	
	-- if we reach here, we were unable to parse the line
	--  (note there is very little that isn't parsed)
end



--[[
	
	Skill Names (for Temporary Morale & Buff/Debuff tracking)
	
	> Temporary Morale Skill Names need specify both how the skill name appears in the combat log, as
	    well as how it appears on the effect tooltip.
	
	> Buff Names must match exactly how the name of a skill appears in the effect tooltip.
	> Benefit/Debuff/Crowd-Control Names must match exactly how the name of a skill appears in the combat log.
	
--]]

-- 0) Temporary Morale Skills {combat log name, effect name}

-- Captain
L["ShieldOfTheDunedainTM"] = {"Shield of the D\195\186nedain","Shield of the D\195\186nedain"};
-- Champion
L["TrueHeroicsTM"] = {"True Heroics","True Heroics"};
L["SuddenDefenceTM"] = {"Sudden Defence","Sudden Defence"};
-- Minstrel
L["StoryOfTheHammerhandTM"] = {"Story of the Hammerhand","Story of the Hammerhand"};
L["SongOfTheHammerhandTM"] = {"Song of the Hammerhand","Song of the Hammerhand"};
L["GiftOfTheHammerhandTM"] = {"Gift of the Hammerhand","Gift of the Hammerhand"};
-- Rune-Keeper
L["WordOfExaltationTM"] = {"Word of Exaltation","Word of Exaltation"};
L["EssayOfExaltationTM"] = {"Essay of Exaltation","Word of Exaltation"};

-- 1) Burglar Skills

-- Buffs (effect name)
L["TouchAndGo"] = "Touch and Go";
L["KnivesOut"] = "Knives Out";
L["Mischievous"] = "Mischievous";
L["QuietKnife"] = "QuietKnife";
L["Gambler"] = "Gambler";
L["Feint"] = "Feint";
L["ImprovedFeint"] = "Improved Feint";
-- Debuffs (log name)
L["RevealWeakness"] = "Reveal Weakness";
L["Addle"] = "Addle";
L["TrickDisable"] = "Trick: Disable";
L["TrickCounterDefence"] = "Trick: Counter Defence";
L["TrickImprovedCounterDefence"] = "Trick: Improved Counter Defence";
L["TrickDustInTheEyes"] = "Trick: Dust in the Eyes";
L["TrickEnrage"] = "Trick: Enrage";
L["ASmallSnag"] = "A Small Snag";
L["QuiteASnag"] = "Quite A Snag";
-- Crowd Control (log name)
L["Riddle"] = "Riddle";
L["ImprovedRiddle"] = "Improved Riddle";
L["Confound"] = "Confound";
L["StartlingTwist"] = "Startling Twist";
L["ImprovedStartlingTwist"] = "Improved Startling Twist";
L["AdvancedStartlingTwist"] = "Advanced Startling Twist";
L["ExploitOpening"] = "Exploit Opening";
L["Trip"] = "Trip";
L["Marbles"] = "Marbles";

-- 2) Captain Skills

-- Buffs (effect name)
L["MusterCourage"] = "Muster Courage";
L["InHarmsWay"] = "In Harm's Way";
L["WarCry"] = "War-cry";
L["BladeOfElendil"] = "Blade of Elendil";
L["Motivated"] = "Motivated";
L["OnGuard"] = "On Guard";
L["RelentlessAttack"] = "Relentless Attack";
L["Focus"] = "Focus";
L["ShieldBrother"] = "Shield-brother";
L["WatchfulShieldBrother"] = "Watchful Shield-brother";
L["SongBrother"] = "Song-brother";
L["BladeBrother"] = "Blade-brother";
L["ToArmsShieldBrother"] = "To Arms (Shield-brother)";
L["ToArmsFellowshipShieldBrother"] = "To Arms (Fellowship Shield-brother)";
L["ToArmsSongBrother"] = "To Arms (Song-brother)";
L["ToArmsFellowshipSongBrother"] = "To Arms (Fellowship Song-brother)";
L["ToArmsBladeBrother"] = "To Arms (Blade-brother)";
L["ToArmsFellowshipBladeBrother"] = "To Arms (Fellowship Blade-brother)";
L["StrengthOfWillShieldBrother"] = "Strength of Will (Shield-brother)";
L["StrengthOfWillFellowshipShieldBrother"] = "Strength of Will (Fellowship Shield-brother)";
L["StrengthOfWillSongBrother"] = "Strength of Will (Song-brother)";
L["StrengthOfWillFellowshipSongBrother"] = "Strength of Will (Fellowship Song-brother)";
L["StrengthOfWillBladeBrother"] = "Strength of Will (Blade-brother)";
L["StrengthOfWillFellowshipBladeBrother"] = "Strength of Will (Fellowship Blade-brother)";
L["RallyingCry"] = "Rallying Cry";
L["InDefenceOfMiddleEarth"] = "In Defence of Middle-earth";
L["DefensiveStrike"] = "Defensive Strike";
L["ImprovedDefensiveStrike"] = "Improved Defensive Strike";
L["LastStand"] = "Last Stand";
-- Debuffs (log name)
L["NobleMark"] = "Noble Mark";
L["TellingMark"] = "Telling Mark";
L["RevealingMark"] = "Revealing Mark";

-- 3) Champion Skills

-- Buffs (effect name)
L["Fervour"] = "Fervour";
L["Glory"] = "Glory";
L["Ardour"] = "Ardour";
L["ControlledBurn"] = "Controlled Burn";
L["Flurry"] = "Flurry";
L["SuddenDefence"] = "Sudden Defence";
L["SeekingBlades"] = "Seeking Blades";
L["Adamant"] = "Adamant";
L["Invincible"] = "Invincible";
-- Benefits (log name)
L["EbbingIre"] = "Ebbing Ire";
L["RisingIre"] = "Rising Ire";

-- 4) Guardian Skills

-- Buffs (effect name)
L["Protection"] = "Protection";
L["ProtectionByTheSword"] = "Protection by the Sword";
L["ShieldWall"] = "Shield Wall";
L["GuardiansBlockStance"] = "Guardian's Block Stance";
L["GuardiansParryStance"] = "Guardian's Parry Stance";
L["Overpower"] = "Overpower";
L["GuardiansThreatStance"] = "Guardian's Threat Stance";
L["GuardiansPledge"] = "Guardian's Pledge";
L["GuardiansWard"] = "Guardian's Ward";
L["ImprovedGuardiansWard"] = "Improved Guardian's Ward";
L["GuardiansWardTactics"] = "Guardian's Ward Tactics";
L["ImprovedGuardiansWardTactics"] = "Improved Guardian's Ward Tactics";
L["WarriorsBlock"] = "Warrior's Block";
L["WarriorsParry"] = "Warrior's Parry";
L["WarriorsPower"] = "Warrior's Power";
L["WarriorsThreat"] = "Warrior's Threat";
-- Debuffs (log name)
L["ImprovedOverwhelm"] = "Improved Overwhelm";

-- 5) Hunter Skills

-- Buffs (effect name)
L["StanceStrength"] = "Stance: Strength";
L["StancePrecision"] = "Stance: Precision";
L["StanceEndurance"] = "Stance: Endurance";
L["BurnHot"] = "Burn Hot";
L["CoolBurn"] = "Cool Burn";
L["Fleetness"] = "Fleetness";
L["ImprovedFleetness"] = "Improved Fleetness";
L["SwiftStroke"] = "Swift Stroke";
L["NeedfulHaste"] = "Needful Haste";
L["HuntersArt"] = "Hunter's Art";
-- Crowd Control (log name)
L["DazingBlow"] = "Dazing Blow";
L["ImprovedDazingBlow"] = "Improved Dazing Blow";
L["DistractingShot"] = "Distracting Shot";
L["RainOfThorns"] = "Rain of Thorns";
L["CryOfThePredator"] = "Cry of the Predator";
L["BardsArrow"] = "Bard's Arrow";
L["TrapDamage"] = "Trap Damage";

-- 6) Lore-Master Skills

-- Buffs (effect name)
L["AirLore"] = "Air-lore";
L["ContinualAirLore"] = "Continual Air-lore";
L["SignOfPowerRighteousness"] = "Sign of Power: Righteousness";
L["SignOfPowerVigilance"] = "Sign of Power: Vigilance";
L["SignOfTheWildRage"] = "Sign of the Wild: Rage";
L["ImprovedSignOfTheWildRage"] = "Improved Sign of the Wild: Rage";
L["SignOfTheWildProtection"] = "Sign of the Wild: Protection";
-- Debuffs (log name)
L["KnowledgeOfTheLoreMaster"] = "Knowledge of the Lore-master";
L["GustOfWind"] = "Gust of Wind";
L["FireLore"] = "Fire-lore";
L["WindLore"] = "Wind-lore";
L["FrostLore"] = "Frost-lore";
L["AncientCraft"] = "Ancient Craft";
L["SignOfPowerCommand"] = "Sign of Power: Command";
L["ImprovedSignOfPowerCommand"] = "Improved Sign of Power: Command";
L["SignOfPowerSeeAllEnds"] = "Sign of Power: See All Ends";
-- Crowd Control (log name)
L["BlindingFlash"] = "Blinding Flash";
L["ImprovedBlindingFlash"] = "Improved Blinding Flash";
L["BaneFlare"] = "Bane Flare";
L["HerbLore"] = "Herb-lore";
L["CrackedEarth"] = "Cracked Earth";

-- 7) Minstrel Skills

-- Buffs (effect name)
L["AnthemOfWar"] = "Anthem of War";
L["AnthemOfTheFreePeoples"] = "Anthem of the Free Peoples";
L["AnthemOfProwess"] = "Anthem of Prowess";
L["AnthemOfComposure"] = "Anthem of Composure";
L["TheMelodyOfBattle"] = "The Melody of Battle";
L["InspireFellows"] = "Inspire Fellows";
L["SoliloquyOfSpirit"] = "Soliloquy of Spirit";
L["ImprovedChordOfSalvation"] = "Improved Chord of Salvation";
L["TaleOfHeroism"] = "Tale of Heroism";
L["TaleOfBattle"] = "Tale of Battle";
L["TaleOfWarding"] = "Tale of Warding";
L["TaleOfWardingAndHope"] = "Tale of Warding and Hope";
L["TaleOfFrostAndFlame"] = "Tale of Frost and Flame";
L["TaleOfFrostAndFlamesBattle"] = "Tale of Frost and Flame's Battle";
L["TaleOfWardingAndHeroism"] = "Tale of Warding and Heroism";
L["SymphonyOfTheHopefulHeart"] = "Symphony of the Hopeful Heart";
L["Harmony"] = "Harmony";
L["WarSpeech"] = "WarSpeech";
L["AnthemOfCompassion"] = "Anthem of Compassion";
L["AnthemOfTheThirdAge"] = "Anthem of the Third Age";
L["AnthemOfTheThirdAgeWarSpeech"] = "Anthem of the Third Age (War-speech)";
L["AnthemOfTheThirdAgeHarmony"] = "Anthem of the Third Age (Harmony)";
L["MinorBallad"] = "Minor Ballad";
L["MajorBallad"] = "Major Ballad";
L["PerfectBallad"] = "Perfect Ballad";
L["StillAsDeath"] = "Still As Death";
-- Crowd Control (log name)
L["SongOfTheDead"] = "Song of the Dead";
L["InvocationOfElbereth"] = "Invocation of Elbereth";

-- 8) Rune-Keeper Skills

-- Buffs (effect name)
L["DoNotFallToStorm"] = "Do Not Fall to Storm";
L["DoNotFallToFlame"] = "Do Not Fall to Flame";
L["DoNotFallToWinter"] = "Do Not Fall to Winter";
L["DoNotFallThisDay"] = "Do Not Fall This Day";
L["ShallNotFallThisDay"] = "Shall Not Fall This Day";
L["PreludeToHope"] = "Prelude to Hope";
L["RuneOfRestoration"] = "Rune of Restoration";
L["WritOfHealthTier1"] = "Writ of Health - Tier 1";
L["WritOfHealthTier2"] = "Writ of Health - Tier 2";
L["WritOfHealthTier3"] = "Writ of Health - Tier 3";
L["OurFatesEntwined"] = "Our Fates Entwined";
L["AllFatesEntwined"] = "All Fates Entwined";
L["GloriousForeshadowing"] = "Glorious Foreshadowing";
L["WondrousForeshadowing"] = "Wondrous Foreshadowing";

-- 9) Warden Skills

-- Buffs (effect name)
L["Conviction"] = "Conviction";
L["DeterminationStance"] = "Determination Stance";
L["Conservation"] = "Conservation";
L["Recklessness"] = "Recklessness";
L["WayOfTheWarden"] = "Way of the Warden";
L["ShieldBashBlock"] = "Shield-bash - Block";
L["WallOfSteelParry"] = "Wall of Steel - Parry";
L["AdroitManoeuvre"] = "Adroit Manoeuvre";
L["WardensTriumph"] = "Warden's Triumph";
L["DefensiveStrikeBlock"] = "Defensive Strike - Block";
L["Persevere"] = "Persevere";
L["ShieldMastery"] = "Shield-mastery";
L["ShieldDefence"] = "Shield-defence";
L["ShieldTactics"] = "Shield-tactics";
L["DanceOfBattleEvade"] = "Dance of Battle - Evade";
L["TacticallySound"] = "Tactically Sound";
L["T1HealOverTime"] = "Tier 1 Heal over Time";
L["T2HealOverTime"] = "Tier 2 Heal over Time";
L["T3HealOverTime"] = "Tier 3 Heal over Time";
L["T4HealOverTime"] = "Tier 4 Heal over Time";

-- 10) Racial Skills
L["DutyBound"] = "Duty Bound";

